<?php
/**
* @version $Id: controller.php $
* @version		2.6.6 11/05/2019
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;
if (!defined('DS')) define('DS', DIRECTORY_SEPARATOR);

require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'legacy.php';
require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'user.php';
require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'user_event.php';

jimport('joomla.application.component.controller');

class MyjspaceController extends JControllerLegacy
{
// Displays a view
	function display($cachable = false, $urlparams = false)
	{
		// Load & add the menu
		require_once JPATH_COMPONENT.DS.'helpers'.DS.'myjspace.php';
		MyJspaceHelper::addSubmenu(JRequest::getCmd('view', 'myjspace'));

		switch ($this->getTask())
		{
			case 'edit' :
			{
				JRequest::setVar('view', 'page');
			} break;
			case 'remove' :
			{
				JRequest::setVar('task', 'remove');
			} break;
			case 'add' :
			{
				// If no root pages folder existing & root page folder supposed to be used
				// Config
				$pparams = JComponentHelper::getParams('com_myjspace');

				// Test itself
				if ($pparams->get('link_folder', 1) == 1 && !BSHelperUser::IsDirW(BSHelperUser::getRootFoldername())) { // No 'myjsp' folder ?
					$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=url', false)); // Go to create it
					return;
				}

				$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=createpage', false));
			} break;
		}

		// Check main mandatory config & alert message
		BSUserEvent::check_mandatory_msg();

		parent::display();
	}

// Create an empty page or a page with a model
	function adm_create_page()
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$pagename = JRequest::getVar('mjs_pagename', '');
		$user_name = JRequest::getVar('mjs_username', '');
		$user_id = JRequest::getInt('mjs_userid', 0);
		$mjs_model_page = JRequest::getInt('mjs_model_page', 0);

		$pparams = JComponentHelper::getParams('com_myjspace');
		$nb_max_page = $pparams->get('nb_max_page', 1);

		if ($user_id > 0)
			$user = JFactory::getUser($user_id); // J1.6+
		else if ($user_name != '')
			$user = JFactory::getUser($user_name); // J!1.5
		else
			$user = JFactory::getUser(); // Current user

		$user_page = New BSHelperUser();

		// Model page
		$catid = 0;
		$model_page = 0;
		if ($mjs_model_page != 0) {
			$model_pagename_tab = BSUserEvent::model_pagename_list();
			if (array_key_exists($mjs_model_page, $model_pagename_tab)) {
				$catid = $model_pagename_tab[$mjs_model_page]['catid'];
				$model_page = $model_pagename_tab[$mjs_model_page]['pagename'];				
			}
		}

		if ($pagename == '')
			$pagename = $user_page->getPagenameFree(basename($pparams->get('auto_pagename_rule', '#username')), $user, $catid);
		else {
			$pagename_check = $user_page->getPagenameFree($pagename, $user, $catid);
			if (BSHelperUser::stringURLSafe($pagename) != $pagename_check)
				$pagename = $pagename_check; // New page name already exists, so we use the automatic proposal
		}
		if (($user) && $pagename != '') {
			$list_page_tab = $user_page->getListPageId($user->id);
			if (count($list_page_tab) >= $pparams->get('nb_max_page',1))
				$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=pages', false), JText::_('COM_MYJSPACE_USERPAGEMAXREACH'), 'error');			
			else {
				$id = BSUserEvent::adm_save_page_conf(0, $user->id, $pagename, $pparams->get('user_mode_view_default', 1), '', $pparams->get('user_mode_edit_default', 0), '', '', '', '', $model_page, $catid, null, '', null, null, 'admin');

				if ($id > 0)
					$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=page&task=edit&id='.$id, false));

				return;
			}
		} else // User do no exist
			$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=pages', false), JText::_('COM_MYJSPACE_NOTALLOWED'), 'error');
	}

// Remove the personal page record from the database and folder & files from disk
	function remove()
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$pageid_tab = JRequest::getVar('cid', array(0));

		BSUserEvent::adm_page_remove($pageid_tab, JRoute::_('index.php?option=com_myjspace&view=pages', false), 'admin');
	}

// Save content & details
	function adm_save_page_all() {
		$this->adm_save_page_content(null); // Save content
		$this->adm_save_page(); // Save details
	}

// Save (update) page details 'only'
	function adm_save_page($url = '')
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$pparams = JComponentHelper::getParams('com_myjspace');

		$id = JRequest::getInt('id', 0);
	
		$prefix_publish = (version_compare(JVERSION, '1.6.0', 'ge')) ? 'jform_' : '';

		$pagename = JRequest::getVar('mjs_pagename', '');
		$blockview = JRequest::getVar('mjs_mode_view', $pparams->get('user_mode_view_default', 1));
		$blockedit = JRequest::getVar('mjs_mode_edit', 0);
		$resethits = JRequest::getVar('resethits', 'no');
		$publish_up = JRequest::getVar($prefix_publish.'publish_up', '');
		$publish_down = JRequest::getVar($prefix_publish.'publish_down', '');
		$metakey = JRequest::getVar('mjs_metakey', '');
		$mjs_template = JRequest::getVar('mjs_template', '');
		$mjs_categories = JRequest::getInt('mjs_categories', 0);
		$user_id = JRequest::getInt('mjs_userid', 0);
		$mjs_userread = JRequest::getVar('mjs_userread', '');

		if ($pparams->get('share_page', 0) != 0)
			$mjsp_share = JRequest::getInt('mjsp_share', 0);
		else
			$mjsp_share = null;

		$mjs_language = JRequest::getVar('mjs_language', '');

		if ($pparams->get('language_filter', 0) == 2) { // Associations
			$associations = JRequest::getVar('associations', array(0));		
			$associations[$mjs_language] = $id;
			if (BSHelperUser::setAssociations($associations) === -1)
				JError::raiseNotice(100, JText::_('COM_MYJSPACE_ASSOCIATION_ALL_ERROR'));
		}

		// Get J!3.1+ tags
		$metadata = JRequest::getVar('metadata', array(0));
		$tags = (array_key_exists('tags', $metadata)) ? $metadata['tags'] : array();

		if (version_compare(JVERSION, '1.6.0', 'lt')) { // J!1.5
			$user_name = JRequest::getVar('mjs_username', '');
			$user = JFactory::getUser($user_name);
			if ($user)
				$user_id = $user->id;
			else
				$user_id = 0; // No change
		}

		if ($url == '')
			$url = 'index.php?option=com_myjspace&view=page&id='.$id;

		if ($resethits != 'yes') {
			BSUserEvent::adm_save_page_conf($id, $user_id, $pagename, $blockview, $mjs_userread, $blockedit, $publish_up, $publish_down, $metakey, $mjs_template, 0, $mjs_categories, $mjsp_share, $mjs_language, $tags, JRoute::_($url, false), 'admin2');
		} else {
			BSUserEvent::adm_reset_page_access($id, JRoute::_($url, false), 'admin');
		}
	}

// Save (update) page details 'only' & exit to page list
	function adm_save_page_exit()
	{
		$this->adm_save_page('index.php?option=com_myjspace&view=pages');
	}  

// Upload file for user page
	function upload_file()
	{
		(JRequest::checkToken('post') || JSession::checkToken('get')) or jexit(JText::_('JINVALID_TOKEN'));

		$id = JRequest::getInt('id', 0);
		$drag_drop = JRequest::getInt('drag_drop', 0);

		$layout = JRequest::getVar('layout', '');
		if ($layout != '')
			$layout = '&tmpl=component&layout='.$layout;

		$type = JRequest::getVar('type', 'undefined');
		if ($type != '')
			$type = '&type='.$type;

		$from = JRequest::getVar('from', 1);
		if ($from != '')
			$type .= '&from='.$from;

		$url = JRoute::_('index.php?option=com_myjspace&view=page&id='.$id.$layout.$type, false);

		if (!isset($_FILES['upload_file']))
			return;
		$FileObject = $_FILES['upload_file'];

		if ($drag_drop == 1 && $layout == '') // Case = 'default' view, else 'upload'
			$url = null;	

		BSUserEvent::adm_upload_file($id, $FileObject, $url, 'admin');
	}

// Delete file from user page
	function delete_file()
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$id = JRequest::getInt('id', 0);

		$layout = JRequest::getVar('layout', '');
		if ($layout != '')
			$layout = '&tmpl=component&layout='.$layout;

		$type = JRequest::getVar('type', 'undefined');
		if ($type != '')
			$type = '&type='.$type;

		$from = JRequest::getVar('from', 1);
		if ($from != '')
			$type .= '&from='.$from;

		$file_name = JRequest::getVar('delete_file');
		BSUserEvent::adm_delete_file($id, $file_name, JRoute::_('index.php?option=com_myjspace&view=page&id='.$id.$layout.$type, false), 'admin');
	}

// Save(update) page content 'only' & exit to page list
	function adm_save_page_content_exit()
	{
		$this->adm_save_page_content('index.php?option=com_myjspace&view=pages');
	}	

// Save(update) page content 'only'
	function adm_save_page_content($url = '')
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'util.php';

		$id = JRequest::getInt('id', 0);

		$content = JRequest::getVar('mjs_content', '@@vide@@', 'POST', 'STRING', JREQUEST_ALLOWRAW);
		if ($content == '@@vide@@') { // To allow really empty page
			$this->setRedirect(JRoute::_('index.php'), JText::_('COM_MYJSPACE_ERRUPDATINGPAGE'), 'error');
			return;
		}

		$pparams = JComponentHelper::getParams('com_myjspace');

		if ($pparams->get('editor_bbcode', 1) == 1) {
			$error = 0;
			$content = BS_Util::bs_bbcode($content, $pparams->get('editor_bbcode_width', 800), $pparams->get('editor_bbcode_height'), $error);
			if ($error != 0)
				JError::raiseNotice(100, JText::_('COM_MYJSPACE_ERROBBCODE'));
		}

		if ($url !== null) {
			if ($url == '')
				$url = JRoute::_('index.php?option=com_myjspace&view=page&id='.$id, false);
			$url = JRoute::_($url, false);
		}

		BSUserEvent::adm_save_page_content($id, $content, $pparams->get('name_page_max_size', 92160), $url, 'admin');
	}

// Rename the personal Root pages folder or sub-folders using naming convention
	function adm_ren_alias_folders()
	{
		JSession::checkToken('get') or jexit(JText::_('JINVALID_TOKEN'));
		BSUserEvent::adm_recompute_foldername();

		$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=help', false), JText::_('COM_MYJSPACE_PAGENAME_KO_FIXED'), 'message');
	}

// Rename/create/move the personal Root pages folder or sub-folders
	function adm_ren_rootfolder()
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$pparams = JComponentHelper::getParams('com_myjspace');
		$link_folder = $pparams->get('link_folder', 1);
		$foldername_redirect_url = $pparams->get('foldername_redirect_url', 'index.php');

		$keep = JRequest::getInt('keep', 0);
		$foldername_new = trim(trim(JRequest::getVar('mjs_foldername')), '/'); // White-space & '/' stripped from the beginning and end
		$foldername_old = BSHelperUser::getRootFoldername();
 
		$url = JRoute::_('index.php?option=com_myjspace&view=url', false);
		
		// Check if alias naming is ok
		if (BSHelperUser::countOldAlias()) {
			$this->setRedirect($url, str_replace('TOKEN', JSession::getFormToken(), JText::_('COM_MYJSPACE_PAGENAME_KO')), 'warning');
			return;
		}
		// Check if all pages folders exists and OK (if check version OK => all directories exists and correct ...)
		$nb_index_ko = BSHelperUser::checkversionIndexPage(false); // Check for all pages
		if ($nb_index_ko) {
			$this->setRedirect($url, str_replace('TOKEN', JSession::getFormToken(), JText::sprintf('COM_MYJSPACE_ADMIN_CHECK_FOLDER_2', $nb_index_ko)), 'warning');
			return;
		}

		if (BSHelperUser::checkFoldername($foldername_new)) { // Test if characters allowed
			set_time_limit(0);

			if (($retour = BSHelperUser::updateRootFoldername($foldername_new, $link_folder, $keep, $foldername_redirect_url))) {
				if ($foldername_old != $foldername_new && $link_folder == 1 && $retour != 1) { // Rename folders inside all pages content !
//					if ($retour == 30) { // To optimize, but test can be deleted and use BSUserEvent::adm_recompute_foldername();
//						BSHelperUser::renameFoldernameAll($foldername_old, $foldername_new); // DB: Rename 'foldername' field in DB with new rootfoldername
//						BSUserEvent::adm_rename_folder_in_pages($foldername_old, $foldername_new); // DB: Change pages folder into page content
//					} else {
						BSUserEvent::adm_recompute_foldername();
//					}
				}
				$this->setRedirect($url, JText::_('COM_MYJSPACE_FOLDERNAMEUPDATED'), 'message');
			} else {
				$this->setRedirect($url, JText::_('COM_MYJSPACE_ERRUPDATINGFOLDERNAMEFILE'), 'error');
			}
		} else {
			$this->setRedirect($url, JText::_('COM_MYJSPACE_NOTVALIDFOLDERNAME'), 'error');
		}
	}

// Re-Create folders and link pages for all personal pages
	function adm_create_folder()
	{
		if (JRequest::checkToken('get') && JRequest::checkToken('post'))
			jexit(JText::_('JINVALID_TOKEN'));

		set_time_limit(0);	
		list($retour, $msg) = BSUserEvent::adm_create_folder();
		$url = JRoute::_('index.php?option=com_myjspace&view=tools', false);
		if ($retour > 0)
			$this->setRedirect($url, JText::_($msg), 'error');
		else
			$this->setRedirect($url, JText::_($msg), 'message');
	}

// Delete folders and link pages for all personal pages
	function adm_delete_folder()
	{
		if (JRequest::checkToken('get') && JRequest::checkToken('post'))
			jexit(JText::_('JINVALID_TOKEN'));

		set_time_limit(0);
		list($retour, $msg) = BSUserEvent::adm_delete_folder();
		$url = JRoute::_('index.php?option=com_myjspace&view=tools', false);
		if ($retour > 0)
			$this->setRedirect($url, JText::_($msg), 'warning');
		else
			$this->setRedirect($url, JText::_($msg), 'message');
	}

// Delete all empty pages (= content + folder empty)
	function adm_delete_empty_pages()
	{
		if (JRequest::checkToken('get') && JRequest::checkToken('post'))
			jexit(JText::_('JINVALID_TOKEN'));

		set_time_limit(0);
		list($retour, $msg) = BSUserEvent::adm_delete_empty_pages();
		$url = JRoute::_('index.php?option=com_myjspace&view=tools', false);
		if ($retour > 0)
			$this->setRedirect($url, JText::_($msg), 'warning');
		else
			$this->setRedirect($url, JText::_($msg), 'message');
	}

// Other tools
	function other_tools()
	{
		if (JRequest::checkToken('get') && JRequest::checkToken('post'))
			jexit(JText::_('JINVALID_TOKEN'));

		$id = JRequest::getVar('id', '');

		// MyJspace Plugins
		JPluginHelper::importPlugin('myjspace'); // Import & call the constructor

		// Tools plugin
		$allow_recompute_foldername = false;
		$dispatcher	= JDispatcher::getInstance();
		$dispatcher->trigger('onMyJspaceTools', array($id, 1)); // List of labels 

		$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=tools', false));
	}
	
	function page_cancel()
	{
		JRequest::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$this->setRedirect(JRoute::_('index.php?option=com_myjspace&view=pages', false));
	}
}
?>
