<?php
/**
* @version $Id: script.BSMyJspace.php $
* @version		2.6.9 22/08/2019
* @package		BSMyJspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2018 - 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die();

class Pkg_BSMyJspaceInstallerScript
{
	protected $minimumPHPVersion = '5.2.4';
	protected $minimumJoomlaVersion = '1.6.0';
	protected $maximumJoomlaVersion = '3.99.99';
	protected $currentMyJspaceVersion = '';
	protected $componentName = 'BS MyJspace pack';

	/**
	 * Joomla! pre-flight event. This runs before Joomla! installs or updates the package. This is our last chance to
	 * tell Joomla! if it should abort the installation.
	 *
	 * @param   string                     $type    Installation type (install, update, discover_install)
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  boolean  True to let the installation proceed, false to halt the installation
	 */
	public function preflight($type, $parent)
	{

		// Get the Package version
		$file = $parent->getParent()->getPath('source').'/pkg_BSMyJspace.xml';
		libxml_use_internal_errors(true);
		if (file_exists($file)) {
			$xml = simplexml_load_file($file);

			if (isset($xml) && isset($xml->version))
				$this->currentMyJspaceVersion = (string)$xml->version;
		}

		if (version_compare(JVERSION, $this->minimumJoomlaVersion, 'lt')) { // Check Joomla! version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least Joomla! '.$this->minimumJoomlaVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		if (version_compare(JVERSION, $this->maximumJoomlaVersion, 'ge')) { // Check Joomla! version for component compatibility
			JFactory::getApplication()->enqueueMessage('Joomla! '.$this->maximumJoomlaVersion.' is the maximum version to install this '.$this->componentName.' '.$this->currentMyJspaceVersion.' (use a more recent pack)', 'error');
			return false;
		}

		if (version_compare(PHP_VERSION, $this->minimumPHPVersion, 'lt')) { // Check PHP version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least PHP '.$this->minimumPHPVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		$txt = '
	<div style="text-align: left;">
		<span><img src="components/com_myjspace/images/myjspace.png" alt="BS MyJspace" /> BS MyJspace '.$this->currentMyJspaceVersion.' - manages personal pages system for your users</span>
		<br /><br />
		<div class="button2-left">
			<div class="blank">
				<a class="modal-button btn" href="index.php?option=com_myjspace&amp;view=help">Finish and Check</a>
			</div>
		</div>
		<br />
		<ul>
			<li>Depending of your choices (read the doc), you may have to <a href="index.php?option=com_myjspace&amp;view=url">create the folder "myjsp"</a> (or your favorite name)</li>
			<li>If you are upgrading you may have to recreate the index files, please <a href="index.php?option=com_myjspace&amp;view=help">check</a></li>
			<li>If you are upgrading from a BS MyJspace version &lt; 2.4.0 you have to re-set the search view options on Menu Options, if used</li>
		</ul>
	</div>';
		echo $txt;

		return true;
	}

	/**
	 * Runs on uninstallation
	 *
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  bool
	 */
	public function uninstall($parent)
	{
		if (!$this->exists_table('myjspace')) {
			$msg = "
			<p>
				<div><strong>Bye bye :-(</strong></div>
				<div>The MyJspace content table(s) and table have been removed during this uninstall process.</div>
				<div>You need to delete the 'myjsp' folder, subfolders &amp; files <strong>manually</strong>, if any.</div>
			</p>
			";
		} else {
			$msg = "
			<p>
				<div><strong>Bye bye :-(</strong></div>
				<div>The MyJspace table(s) content, tables, folders and files <strong>are not</strong> removed during this uninstall process.</div>
				<div>Set the option 'Uninstall table and content' to 'yes' (after reinstall &amp; new uninstall!) to delete the table(s) and tables(s) content.</div>
				<div>You need to delete the 'myjsp' folder, subfolders &amp; files <strong>manually</strong>, if any.</div>
			</p>
			";
		}

		JFactory::getApplication()->enqueueMessage($msg, 'notice');

		return true;
	}

	// ----------------------------- extra fct -------------------

	/**
	 * Check if a table exists
	 *
	 * @param 		$tablename  example: 'myjspace'
	 *
	 * @return  bool
	 */
	private function exists_table($tablename = null) 
	{
		if ($tablename == null)
			return false;

		$config = new JConfig();

		$ma_table = $config->dbprefix.$tablename;
		$liste_tables = JFactory::getDbo()->getTableList();

		if (in_array($ma_table, $liste_tables)) {
			return true;
		}

		return false;
	}
}
